
.. blogpost::
    :title: pivottablejs
    :keywords: pivottablejs
    :date: 2016-12-04
    :categories: module

    A simple module to display a dataframe in a notebook
    with javascript:
    `pivottablejs <https://github.com/nicolaskruchten/pivottable>`_.
    You can check the notebook :ref:`pivottablejsrst`.
